


{ // setup
clear all

cap log close

di "Set global $home as project STATA directory."
global home "STOP - SET HOME DIRECTORY"									



global input "$home/Input"
global code "$home/Code"
global output "$home/Output"
global temp "$home/Temp"

set more off, perm		

}


{ // Ayres and Brooks -- original
use "$input/lsac_choice.dta", clear

/* Dropping those students who give 'not admitted' as reason for not attending 1st choice school **/ 
drop if esq61a==1

/* Cleaning data - according to codebook these people should skip to esq62 and not answer esq61! **/   
replace esq61a=. if esq59==1  
replace esq61b=. if esq59==1 
replace esq61c=. if esq59==1 

/* Keeping only those students for whom all explanatory vars are available **/   
keep if race1!="" & zlsat!=. & zugpa!=. & gender!="" & tier!=. & esq57!=. & zfygpa!=. 
count

/* Dropping those students who were accepted by only 1 school */   
drop if esq58==1 
count

/* CHOICE DUMMY : =1 for students not at their 1st choice school, =0 for students at their 1st choice school **/   
gen choice2=1  
replace choice2=0 if esq59==1 

// encode first bar passage
encode(bar1), gen(first_bar)
replace first_bar = first_bar - 1
la drop first_bar

/* FYGPA - with choice dummy **/   
xi: reg zfygpa asian black hisp other male tier choice2 esq57 
xi: reg zfygpa male tier choice2 esq57  if race1=="black"
xi: reg zfygpa male tier choice2 esq57  if race1=="white"

// PASS_BAR - with choice dummy  
xi: logit pass_bar asian black hisp other male tier choice2 esq57 
xi: logit pass_bar male tier choice2 esq57  if race1=="black"
xi: logit pass_bar male tier choice2 esq57  if race1=="white"
xi: logit pass_bar zfygpa asian black hisp other male tier choice2 esq57 
xi: logit pass_bar zfygpa male tier choice2 esq57  if race1=="black"
xi: logit pass_bar zfygpa male tier choice2 esq57  if race1=="white"
xi: logit pass_bar ugpa zlsat asian black hisp other male tier choice2 esq57 
xi: logit pass_bar ugpa zlsat male tier choice2 esq57  if race1=="black"
xi: logit pass_bar ugpa zlsat male tier choice2 esq57  if race1=="white"

xi: logit first_bar asian black hisp other male tier choice2 esq57 
xi: logit first_bar male tier choice2 esq57  if race1=="black"
xi: logit first_bar male tier choice2 esq57  if race1=="white"

}


// Ayres and Brooks -- original with Sander data (confirmed that this is the same, just with different labels) and fixing hispanic coding
{ // this replicates the "Reproduction of A-B" columns in Sander (2019)
use "$input/lsac_sander.dta", clear

/* Dropping those students who give 'not admitted' as reason for not attending 1st choice school **/ 
drop if esq61a==1 // this includes 1st, 2nd, and 3rd choicers

/* Cleaning data - according to codebook these people should skip to esq62 and not answer esq61! **/   
replace esq61a=. if esq59==1  
replace esq61b=. if esq59==1 
replace esq61c=. if esq59==1 

/* Keeping only those students for whom all explanatory vars are available **/   
keep if race1!="" & lsat!=. & ugpa!=. & male != . & tier!=. & esq57!=. & zfygpa!=. 
count

/* Dropping those students who were accepted by only 1 school */   
drop if esq58==1 
count

// encode race
encode race1, gen(race_var)
cap drop asian
cap drop black
cap drop hisp
cap drop other_race
gen asian = (race_var == 1) if race_var < .
gen black = (race_var == 2) if race_var < .
gen hisp = (race_var == 3) if race_var < .
gen other_race = (race_var == 4) if race_var < .
la var asian "Asian"
la var black "Black"
la var hisp "Hispanic"
la var other_race "Other Race"

la var male "Male"
la var tier "Tier"
la var esq57 "# Schools Appl."

// encode first bar passage
encode(bar1), gen(first_bar)
recode first_bar (1 = 0) (2 = 1)
la drop first_bar

// encode final bar passage
encode(bar2), gen(ever_bar)
recode ever_bar (1 = 0) (2 = 1)
la drop ever_bar

/* CHOICE DUMMY : =1 for students not at their 1st choice school, =0 for students at their 1st choice school **/   
gen choice2=1  
replace choice2=0 if esq59==1 
la var choice2 "Second Choice"

/* FYGPA - with choice dummy **/   
xi: reg zfygpa asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/first year grades.xls", replace excel label ctitle("A&B, All (1)")
xi: reg zfygpa male tier choice2 esq57  if race1=="black"
outreg2 using "$output/first year grades.xls", append excel label ctitle("A&B, Black (2)")
xi: reg zfygpa male tier choice2 esq57  if race1=="white"
outreg2 using "$output/first year grades.xls", append excel label ctitle("A&B, White (3)")

// Sander Table 4
reg zgpa asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/final grades.xls", replace excel label ctitle("A&B, All (1)")
reg zgpa male tier choice2 esq57  if race1=="black"
outreg2 using "$output/final grades.xls", append excel label ctitle("A&B, Black (2)")
reg zgpa male tier choice2 esq57  if race1=="white"
outreg2 using "$output/final grades.xls", append excel label ctitle("A&B, White (3)")

// EVER PASS_BAR - with choice dummy  
xi: logit ever_bar asian black hisp other_race male tier choice2 esq57
outreg2 using "$output/ever bar passage.xls", replace excel label ctitle("A&B, All (1)") 
xi: logit ever_bar male tier choice2 esq57  if race1=="black"
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("A&B, Black (2)") 
xi: logit ever_bar male tier choice2 esq57  if race1=="white"
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("A&B, White (3)") 

// Sander table 5
logit first_bar asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/first time bar passage.xls", replace excel label ctitle("A&B, All (1)")
logit first_bar male tier choice2 esq57  if race1=="black"
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("A&B, Black (2)")
logit first_bar male tier choice2 esq57  if race1=="white"
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("A&B, White (3)")

}


{ // Ayres and Brooks -- fixing the missing second choice answer error pointed out in Sander (and using race1 instead of race dummies)
use "$input/lsac_sander.dta", clear

/* Dropping those students who give 'not admitted' as reason for not attending 1st choice school **/ 
drop if esq61a==1

/* Cleaning data - according to codebook these people should skip to esq62 and not answer esq61! **/   
replace esq61a=. if esq59==1  
replace esq61b=. if esq59==1 
replace esq61c=. if esq59==1 

/* Keeping only those students for whom all explanatory vars are available, including first year gpa **/   
keep if race1!="" & lsat!=. & ugpa!=. & male != . & tier!=. & esq57!=. & zfygpa!=. 
count

/* Dropping those students who were accepted by only 1 school */   
drop if esq58==1 
count

/* drop those that are missing response to Q59 */
count if esq59 != .
drop if esq59 == .
count

// encode race
encode race1, gen(race_var)
cap drop asian
cap drop black
cap drop hisp
cap drop other_race
gen asian = (race_var == 1) if race_var < .
gen black = (race_var == 2) if race_var < .
gen hisp = (race_var == 3) if race_var < .
gen other_race = (race_var == 4) if race_var < .
la var asian "Asian"
la var black "Black"
la var hisp "Hispanic"
la var other_race "Other Race"

la var male "Male"
la var tier "Tier"
la var esq57 "# Schools Appl."

/* CHOICE DUMMY : =1 for students not at their 1st choice school, =0 for students at their 1st choice school **/   
gen choice2=1  
replace choice2=0 if esq59==1 
la var choice2 "Second Choice"

// encode first bar passage
encode(bar1), gen(first_bar)
recode first_bar (1 = 0) (2 = 1)
la drop first_bar

// encode final bar passage
encode(bar2), gen(ever_bar)
recode ever_bar (1 = 0) (2 = 1)
la drop ever_bar

/* FYGPA - with choice dummy **/   
xi: reg zfygpa asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/first year grades.xls", excel append label ctitle("A&B Correcting Missing Second Choice, All (4)")
xi: reg zfygpa male tier choice2 esq57  if race1=="black"
outreg2 using "$output/first year grades.xls", excel append label ctitle("A&B Correcting Missing Second Choice, Black (5)")
xi: reg zfygpa male tier choice2 esq57  if race1=="white"
outreg2 using "$output/first year grades.xls", append excel label ctitle("A&B Correcting Missing Second Choice, White (6)")

// Sander Table 4
reg zgpa asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/final grades.xls", append excel label ctitle("A&B Correcting Missing Second Choice, All (4)")
reg zgpa male tier choice2 esq57  if race1=="black"
outreg2 using "$output/final grades.xls", append excel label ctitle("A&B Correcting Missing Second Choice, Black (5)")
reg zgpa male tier choice2 esq57  if race1=="white"
outreg2 using "$output/final grades.xls", append excel label ctitle("A&B Correcting Missing Second Choice, White (6)")

// EVER PASS_BAR - with choice dummy  
xi: logit ever_bar asian black hisp other_race male tier choice2 esq57
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("A&B Correcting Missing Second Choice, All (4)") 
xi: logit ever_bar male tier choice2 esq57  if race1=="black"
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("A&B Correcting Missing Second Choice, Black (5)") 
xi: logit ever_bar male tier choice2 esq57  if race1=="white"
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("A&B Correcting Missing Second Choice, White (6)") 

// Sander table 5
logit first_bar asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("A&B Correcting Missing Second Choice, All (4)")
logit first_bar male tier choice2 esq57  if race1=="black"
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("A&B Correcting Missing Second Choice, Black (5)")
logit first_bar male tier choice2 esq57  if race1=="white"
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("A&B Correcting Missing Second Choice, White (6)")

}


{ // Ayres and Brooks -- fixing the missing second choice answer pointed out in Sander and including those that are missing first-year grades (and using race1 instead of race dummies)
use "$input/lsac_sander.dta", clear

/* Dropping those students who give 'not admitted' as reason for not attending 1st choice school **/ 
drop if esq61a==1

/* Cleaning data - according to codebook these people should skip to esq62 and not answer esq61! **/   
replace esq61a=. if esq59==1  
replace esq61b=. if esq59==1 
replace esq61c=. if esq59==1 

/* Keeping only those students for whom all explanatory vars are available, excluding first year gpa **/   
keep if race1!="" & lsat!=. & ugpa!=. & male != . & tier!=. & esq57!=. 
count

/* Dropping those students who were accepted by only 1 school */   
drop if esq58==1 
count

/* drop those that are missing response to Q59 */
drop if esq59 == .

// encode race
encode race1, gen(race_var)
cap drop asian
cap drop black
cap drop hisp
cap drop other_race
gen asian = (race_var == 1) if race_var < .
gen black = (race_var == 2) if race_var < .
gen hisp = (race_var == 3) if race_var < .
gen other_race = (race_var == 4) if race_var < .
la var asian "Asian"
la var black "Black"
la var hisp "Hispanic"
la var other_race "Other Race"

la var male "Male"
la var tier "Tier"
la var esq57 "# Schools Appl."

/* CHOICE DUMMY : =1 for students not at their 1st choice school, =0 for students at their 1st choice school **/   
gen choice2=1  
replace choice2=0 if esq59==1 
la var choice2 "Second Choice"

// encode first bar passage
encode(bar1), gen(first_bar)
recode first_bar (1 = 0) (2 = 1)
la drop first_bar

// encode final bar passage
encode(bar2), gen(ever_bar)
recode ever_bar (1 = 0) (2 = 1)
la drop ever_bar

/* FYGPA - with choice dummy **/   
xi: reg zfygpa asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/first year grades.xls", excel append label ctitle("A&B Correcting Missing Second Choice and Not Dropping Missing First Year Grades, All (7)")
xi: reg zfygpa male tier choice2 esq57  if race1=="black"
outreg2 using "$output/first year grades.xls", excel append label ctitle("A&B Correcting Missing Second Choice and Not Dropping Missing First Year Grades, Black (8)")
xi: reg zfygpa male tier choice2 esq57  if race1=="white"
outreg2 using "$output/first year grades.xls", append excel label ctitle("A&B Correcting Missing Second Choice and Not Dropping Missing First Year Grades, White (9)")

// Sander Table 4
reg zgpa asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/final grades.xls", append excel label ctitle("A&B Correcting Missing Second Choice and Not Dropping Missing First Year Grades, All (7)")
reg zgpa male tier choice2 esq57  if race1=="black"
outreg2 using "$output/final grades.xls", append excel label ctitle("A&B Correcting Missing Second Choice and Not Dropping Missing First Year Grades, Black (8)")
reg zgpa male tier choice2 esq57  if race1=="white"
outreg2 using "$output/final grades.xls", append excel label ctitle("A&B Correcting Missing Second Choice and Not Dropping Missing First Year Grades, White (9)")

// EVER PASS_BAR - with choice dummy  
xi: logit ever_bar asian black hisp other_race male tier choice2 esq57
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("A&B Correcting Missing Second Choice and Not Dropping Missing First Year Grades, All (7)") 
xi: logit ever_bar male tier choice2 esq57  if race1=="black"
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("A&B Correcting Missing Second Choice and Not Dropping Missing First Year Grades, Black (8)") 
xi: logit ever_bar male tier choice2 esq57  if race1=="white"
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("A&B Correcting Missing Second Choice and Not Dropping Missing First Year Grades, White (9)") 

// Sander table 5
logit first_bar asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("A&B Correcting Missing Second Choice and Not Dropping Missing First Year Grades, All (7)")
logit first_bar male tier choice2 esq57  if race1=="black"
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("A&B Correcting Missing Second Choice and Not Dropping Missing First Year Grades, Black (8)")
logit first_bar male tier choice2 esq57  if race1=="white"
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("A&B Correcting Missing Second Choice and Not Dropping Missing First Year Grades, White (9)")

}


{ // Sander -- narrow filter
use "$input/lsac_sander.dta", clear

// drop for missing data 
keep if race1!="" & lsat!=. & ugpa!=. & male != . & tier!=. & esq57!=. 
count

// drop first choicers that respond "yes" to q61a 
drop if esq61a == 1 & esq59 == 1
count

// drop first choicers that respond to any part of q61
drop if esq59 == 1 & esq61a != .
drop if esq59 == 1 & esq61b != .
drop if esq59 == 1 & esq61c != .
count

// drop second or third choicers that answer yes to q61a
drop if ((esq59 == 2 | esq59 == 3) & esq61a == 1)
count

// drop second or third choicers that are missing q61a
drop if ((esq59 == 2 | esq59 == 3) & esq61a == .)
count

// drop if only applied to one school
drop if esq57 == 1
count

// Dropping those students who were accepted by only 1 school
drop if esq58 == 1 
count

// dropping students missing q58
drop if esq58 == .

// drop those that are missing response to Q59
drop if esq59 == .
count

/*
// drop those missing a response to q61a?? Sander says that this is the final filtering step,
// but it does not appear to be enacted. At this point, only second and third choicers have answers (and only "no" to this question)
drop if esq61a == . 
count
*/

/* CHOICE DUMMY : =1 for students not at their 1st choice school, =0 for students at their 1st choice school **/   
gen choice2=1  
replace choice2=0 if esq59==1 

// encode race
encode race1, gen(race_var)
cap drop asian
cap drop black
cap drop hisp
cap drop other_race
gen asian = (race_var == 1) if race_var < .
gen black = (race_var == 2) if race_var < .
gen hisp = (race_var == 3) if race_var < .
gen other_race = (race_var == 4) if race_var < .
la var asian "Asian"
la var black "Black"
la var hisp "Hispanic"
la var other_race "Other Race"

la var male "Male"
la var tier "Tier"
la var choice2 "Second Choice"
la var esq57 "# Schools Appl."

// encode first bar passage
encode(bar1), gen(first_bar)
recode first_bar (1 = 0) (2 = 1)
la drop first_bar

// encode final bar passage
encode(bar2), gen(ever_bar)
recode ever_bar (1 = 0) (2 = 1)
la drop ever_bar

// generate took bar variable
//gen took_bar = var changed in dataset so need to update this inlist(bar, "a Passed 1st time", "b Passed 2nd time", "c Failed")

// generate separate second and third choice variables
gen just_second = (esq59 == 2)
gen just_third = (esq59 == 3)

	
/* FYGPA - with choice dummy **/   
reg zfygpa asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/first year grades.xls", excel append label ctitle("Sander Narrow Filter, All (10)")
reg zfygpa male tier choice2 esq57  if race1=="black"
outreg2 using "$output/first year grades.xls", excel append label ctitle("Sander Narrow Filter, Black (11)")
reg zfygpa male tier choice2 esq57  if race1=="white"
outreg2 using "$output/first year grades.xls", append excel label ctitle("Sander Narrow Filter, White (12)")

// Sander Table 4
reg zgpa asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/final grades.xls", append excel label ctitle("Sander Narrow Filter, All (10)")
reg zgpa male tier choice2 esq57  if race1=="black"
outreg2 using "$output/final grades.xls", append excel label ctitle("Sander Narrow Filter, Black (11)")
reg zgpa male tier choice2 esq57  if race1=="white"
outreg2 using "$output/final grades.xls", append excel label ctitle("Sander Narrow Filter, White (12)")

// EVER PASS_BAR - with choice dummy  
xi: logit ever_bar asian black hisp other_race male tier choice2 esq57
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("Sander Narrow Filter, All (10)") 
xi: logit ever_bar male tier choice2 esq57  if race1=="black"
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("Sander Narrow Filter, Black (11)") 
xi: logit ever_bar male tier choice2 esq57  if race1=="white"
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("Sander Narrow Filter, White (12)") 

// Sander table 5
logit first_bar asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("Sander Narrow Filter, All (10)")
logit first_bar male tier choice2 esq57  if race1=="black"
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("Sander Narrow Filter, Black (11)")
logit first_bar male tier choice2 esq57  if race1=="white"
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("Sander Narrow Filter, White (12)")

}


{ // Sander -- wide filter
use "$input/lsac_sander.dta", clear

// drop for missing data 
keep if race1!="" & lsat!=. & ugpa!=. & male!=. & tier!=. & esq57!=.
count

/*
// drop first choicers that respond "yes" to q61a 
drop if esq61a == 1 & esq59 == 1
count

// drop first choicers that respond to any part of q61
drop if esq59 == 1 & esq61a != .
drop if esq59 == 1 & esq61b != .
drop if esq59 == 1 & esq61c != .
count

// drop second or third choicers that answer yes to q61a
drop if ((esq59 == 2 | esq59 == 3) & esq61a == 1)
count

// drop second or third choicers that are missing q61a
drop if ((esq59 == 2 | esq59 == 3) & esq61a == .)
count

// drop if only applied to one school
drop if esq57 == 1
count
*/

// Dropping those students who were accepted by only 1 school
drop if esq58 == 1 
count

/*
// dropping students missing q58
drop if esq58 == .
*/

// drop those that are missing response to Q59
drop if esq59 == .
count


/*
// drop those missing a response to q61a?? Sander says that this is the final filtering step,
// but it does not appear to be enacted. At this point, only second and third choicers have answers (and only "no" to this question)
drop if esq61a == . 
count
*/

/* CHOICE DUMMY : =1 for students not at their 1st choice school, =0 for students at their 1st choice school **/   
gen choice2=1  
replace choice2=0 if esq59==1 

// encode race
encode race1, gen(race_var)
cap drop asian
cap drop black
cap drop hisp
cap drop other_race
gen asian = (race_var == 1) if race_var < .
gen black = (race_var == 2) if race_var < .
gen hisp = (race_var == 3) if race_var < .
gen other_race = (race_var == 4) if race_var < .
la var asian "Asian"
la var black "Black"
la var hisp "Hispanic"
la var other_race "Other Race"

la var male "Male"
la var tier "Tier"
la var esq57 "# Schools Appl."
la var choice2 "Second Choice"

// encode first bar passage
encode(bar1), gen(first_bar)
recode first_bar (1 = 0) (2 = 1)
la drop first_bar

// encode final bar passage
encode(bar2), gen(ever_bar)
recode ever_bar (1 = 0) (2 = 1)
la drop ever_bar

// generate took bar variable
gen took_bar = .
// var changed in dataset so need to update this inlist(bar, "a Passed 1st time", "b Passed 2nd time", "c Failed")

// generate separate second and third choice variables
gen just_second = (esq59 == 2)
gen just_third = (esq59 == 3)



	
/* FYGPA - with choice dummy **/   
reg zfygpa asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/first year grades.xls", excel append label ctitle("Reproduction of Sander Wide Filter, All (13)")
reg zfygpa male tier choice2 esq57  if race1=="black"
outreg2 using "$output/first year grades.xls", excel append label ctitle("Reproduction of Sander Wide Filter, Black (14)")
reg zfygpa male tier choice2 esq57  if race1=="white"
outreg2 using "$output/first year grades.xls", append excel label ctitle("Reproduction of Sander Wide Filter, White (15)")

// Sander Table 4
reg zgpa asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/final grades.xls", append excel label ctitle("Reproduction of Sander Wide Filter, All (13)")
reg zgpa male tier choice2 esq57  if race1=="black"
outreg2 using "$output/final grades.xls", append excel label ctitle("Reproduction of Sander Wide Filter, Black (14)")
reg zgpa male tier choice2 esq57  if race1=="white"
outreg2 using "$output/final grades.xls", append excel label ctitle("Reproduction of Sander Wide Filter, White (15)")

// EVER PASS_BAR - with choice dummy  
xi: logit ever_bar asian black hisp other_race male tier choice2 esq57
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("Reproduction of Sander Wide Filter, All (13)") 
xi: logit ever_bar male tier choice2 esq57  if race1=="black"
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("Reproduction of Sander Wide Filter, Black (14)") 
xi: logit ever_bar male tier choice2 esq57  if race1=="white"
outreg2 using "$output/ever bar passage.xls", append excel label ctitle("Reproduction of Sander Wide Filter, White (15)") 

// Sander table 5
logit first_bar asian black hisp other_race male tier choice2 esq57 
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("Reproduction of Sander Wide Filter, All (13)")
logit first_bar male tier choice2 esq57  if race1=="black"
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("Reproduction of Sander Wide Filter, Black (14)")
logit first_bar male tier choice2 esq57  if race1=="white"
outreg2 using "$output/first time bar passage.xls", append excel label ctitle("Reproduction of Sander Wide Filter, White (15)")

}



{ // monte carlo to determine how the effect of leaving in the AB error observations compares to leaving in any a random group of the observations with the same racial composition that would otherwise be dropped

use "$input/lsac_sander.dta", clear

gen drop_var = 0

/* Dropping those students who give 'not admitted' as reason for not attending 1st choice school **/ 
replace drop_var = 1 if esq61a==1

/* Cleaning data - according to codebook these people should skip to esq62 and not answer esq61! **/   
replace esq61a=. if esq59==1  
replace esq61b=. if esq59==1 
replace esq61c=. if esq59==1 

/* Keeping only those students for whom all explanatory vars are available, including first year gpa **/   
replace drop_var = 1 if race1 == "" | lsat == . | ugpa == . | male == . | tier == . | esq57 == . | zfygpa == .
count

/* Dropping those students who were accepted by only 1 school */   
replace drop_var = 1 if esq58==1 
count


tab race1 if esq59 == .
preserve
	keep if esq59 == . & drop_var != 1
	
	tabout race1 ///
	using "$output/AB Error Race Table.csv" ///
	, replace style(csv) oneway c(freq col) f(0c 1p) ptotal(none) clab(N %)
restore

gen race2 = race1
replace race2 = "other" if inlist(race1,"asian","hisp")


/* drop those that are missing response to Q59 */
replace drop_var = 1 if esq59 == .


// encode race
encode race1, gen(race_var)
cap drop asian
cap drop black
cap drop hisp
cap drop other_race
gen asian = (race_var == 1) if race_var < .
gen black = (race_var == 2) if race_var < .
gen hisp = (race_var == 3) if race_var < .
gen other_race = (race_var == 4) if race_var < .
la var asian "Asian"
la var black "Black"
la var hisp "Hispanic"
la var other_race "Other Race"

la var male "Male"
la var tier "Tier"
la var esq57 "# Schools Appl."

/* CHOICE DUMMY : =1 for students not at their 1st choice school, =0 for students at their 1st choice school **/   
gen choice2=1  
replace choice2=0 if esq59==1 
la var choice2 "Second Choice"

// encode first bar passage
encode(bar1), gen(first_bar)
recode first_bar (1 = 0) (2 = 1)
la drop first_bar

// encode final bar passage
encode(bar2), gen(ever_bar)
recode ever_bar (1 = 0) (2 = 1)
la drop ever_bar




// monte carlo estimate
timer on 1
qui forvalues i = 1/10000 {
	preserve
		local seed_num = 7578926 + `i'
		set seed `seed_num'

		// select random observations to include that would otherwise not be included
		gen rand_sort_order = runiform()
		bys rand_sort_order: replace rand_sort_order = rand_sort_order + _n if _N > 1
		bys rand_sort_order: assert _N == 1
		sort race2 drop_var rand_sort_order 
		gen random_inclusion = 0
		by race2: replace random_inclusion = 1 if ((_n > _N - 87 & race2 ==  "white") | (_n > _N - 11 & race2 == "black") | (_n > _N - 11 & race2 == "other"))

		// filter out those that meet the drop criteria and have not been selected for random inclusion
		if `i' == 1 {
		 drop if drop_var == 1	
		}
		else {
		    drop if drop_var == 1 & random_inclusion == 0
		}	
		

		/* FYGPA - with choice dummy **/   
		xi: reg zfygpa asian black hisp other_race male tier choice2 esq57 
		local beta1 = _b[choice2]
		local p1 = 2 * ttail(e(df_r), abs(_b[choice2]/_se[choice2]))
		xi: reg zfygpa male tier choice2 esq57  if race1=="black"
		local beta2 = _b[choice2]
		local p2 = 2 * ttail(e(df_r), abs(_b[choice2]/_se[choice2]))
		xi: reg zfygpa male tier choice2 esq57  if race1=="white"
		local beta3 = _b[choice2]
		local p3 = 2 * ttail(e(df_r), abs(_b[choice2]/_se[choice2]))

		// Sander Table 4
		reg zgpa asian black hisp other_race male tier choice2 esq57 
		local beta4 = _b[choice2]
		local p4 = 2 * ttail(e(df_r), abs(_b[choice2]/_se[choice2]))
		reg zgpa male tier choice2 esq57  if race1=="black"
		local beta5 = _b[choice2]
		local p5 = 2 * ttail(e(df_r), abs(_b[choice2]/_se[choice2]))
		reg zgpa male tier choice2 esq57  if race1=="white"
		local beta6 = _b[choice2]
		local p6 = 2 * ttail(e(df_r), abs(_b[choice2]/_se[choice2]))

		// EVER PASS_BAR - with choice dummy  
		xi: logit ever_bar asian black hisp other_race male tier choice2 esq57
		local beta7 = _b[choice2]
		local p7 = 2 * ttail(e(df_r), abs(_b[choice2]/_se[choice2]))
		xi: logit ever_bar male tier choice2 esq57  if race1=="black"
		local beta8 = _b[choice2]
		local p8 = 2 * ttail(e(df_r), abs(_b[choice2]/_se[choice2]))
		xi: logit ever_bar male tier choice2 esq57  if race1=="white"
		local beta9 = _b[choice2]
		local p9 = 2 * ttail(e(df_r), abs(_b[choice2]/_se[choice2]))

		// Sander table 5
		logit first_bar asian black hisp other_race male tier choice2 esq57 
		local beta10 = _b[choice2]
		local p10 = 2 * ttail(e(df_r), abs(_b[choice2]/_se[choice2]))
		logit first_bar male tier choice2 esq57  if race1=="black"
		local beta11 = _b[choice2]
		local p11 = 2 * ttail(e(df_r), abs(_b[choice2]/_se[choice2]))
		logit first_bar male tier choice2 esq57  if race1=="white"
		local beta12 = _b[choice2]
		local p12 = 2 * ttail(e(df_r), abs(_b[choice2]/_se[choice2]))
		
		clear 
		set obs 1
		gen sim_num = `i' - 1
		gen fygpa_overall_p = `p1'
		gen fygpa_overall_beta = `beta1'
		gen fygpa_black_p = `p2'
		gen fygpa_black_beta = `beta2'
		gen fygpa_white_p = `p3'
		gen fygpa_white_beta = `beta3'
		gen gpa_overall_p = `p4'
		gen gpa_overall_beta = `beta4'
		gen gpa_black_p = `p5'
		gen gpa_black_beta = `beta5'
		gen gpa_white_p = `p6'
		gen gpa_white_beta = `beta6'
		gen everbar_overall_p = `p7'
		gen everbar_overall_beta = `beta7'
		gen everbar_black_p = `p8'
		gen everbar_black_beta = `beta8'
		gen everbar_white_p = `p9'
		gen everbar_white_beta = `beta9'
		gen firstbar_overall_p = `p10'
		gen firstbar_overall_beta = `beta10'
		gen firstbar_black_p = `p11'
		gen firstbar_black_beta = `beta11'
		gen firstbar_white_p = `p12'
		gen firstbar_white_beta = `beta12'

		if `i' == 1 {
    		save "$temp/monte carlo values", replace
		}
		else {
			cap append using "$temp/monte carlo values"
			save "$temp/monte carlo values", replace
		}
		sleep 10
	restore

}
timer off 1
timer list 1

// determine percentiles
use "$temp/monte carlo values", clear

foreach var of varlist fygpa_overall_p-firstbar_white_beta {
	sort `var' 
	gen pctile = _n / 10001
	tab pctile if sim_num == 0
	drop pctile

}


}



